@@ -5,13 +5,7 @@ import pytest
 
 from wsproto import WSConnection
 from wsproto.connection import SERVER
-from wsproto.events import (
-    AcceptConnection,
-    Event,
-    RejectConnection,
-    RejectData,
-    Request,
-)
+from wsproto.events import AcceptConnection, RejectConnection, RejectData, Request
 from wsproto.extensions import Extension
 from wsproto.typing import Headers
 from wsproto.utilities import (
@@ -62,7 +56,7 @@ def test_connection_request() -> None:
 
 def test_connection_request_bad_method() -> None:
     with pytest.raises(RemoteProtocolError) as excinfo:
-        event = _make_connection_request(
+        _make_connection_request(
             [
                 (b"Host", b"localhost"),
                 (b"Connection", b"Keep-Alive, Upgrade"),
@@ -77,7 +71,7 @@ def test_connection_request_bad_method() -> None:
 
 def test_connection_request_bad_connection_header() -> None:
     with pytest.raises(RemoteProtocolError) as excinfo:
-        event = _make_connection_request(
+        _make_connection_request(
             [
                 (b"Host", b"localhost"),
                 (b"Connection", b"Keep-Alive, No-Upgrade"),
@@ -91,7 +85,7 @@ def test_connection_request_bad_connection_header() -> None:
 
 def test_connection_request_bad_upgrade_header() -> None:
     with pytest.raises(RemoteProtocolError) as excinfo:
-        event = _make_connection_request(
+        _make_connection_request(
             [
                 (b"Host", b"localhost"),
                 (b"Connection", b"Keep-Alive, Upgrade"),
@@ -106,7 +100,7 @@ def test_connection_request_bad_upgrade_header() -> None:
 @pytest.mark.parametrize("version", [b"12", b"not-a-digit"])
 def test_connection_request_bad_version_header(version: bytes) -> None:
     with pytest.raises(RemoteProtocolError) as excinfo:
-        event = _make_connection_request(
+        _make_connection_request(
             [
                 (b"Host", b"localhost"),
                 (b"Connection", b"Keep-Alive, Upgrade"),
@@ -123,7 +117,7 @@ def test_connection_request_bad_version_header(version: bytes) -> None:
 
 def test_connection_request_key_header() -> None:
     with pytest.raises(RemoteProtocolError) as excinfo:
-        event = _make_connection_request(
+        _make_connection_request(
             [
                 (b"Host", b"localhost"),
                 (b"Connection", b"Keep-Alive, Upgrade"),
@@ -199,36 +193,30 @@ def _make_handshake(
         )
     )
     event = client.next_event()
-    return event, nonce
+    return cast(h11.InformationalResponse, event), nonce
 
 
 def test_handshake() -> None:
     response, nonce = _make_handshake([])
 
-    response.headers = sorted(response.headers)  # For test determinism
-    assert response == h11.InformationalResponse(
-        status_code=101,
-        headers=[
-            (b"connection", b"Upgrade"),
-            (b"sec-websocket-accept", generate_accept_token(nonce)),
-            (b"upgrade", b"WebSocket"),
-        ],
-    )
+    assert response.status_code == 101
+    assert sorted(response.headers) == [
+        (b"connection", b"Upgrade"),
+        (b"sec-websocket-accept", generate_accept_token(nonce)),
+        (b"upgrade", b"WebSocket"),
+    ]
 
 
 def test_handshake_extra_headers() -> None:
     response, nonce = _make_handshake([], accept_headers=[(b"X-Foo", b"bar")])
 
-    response.headers = sorted(response.headers)  # For test determinism
-    assert response == h11.InformationalResponse(
-        status_code=101,
-        headers=[
-            (b"connection", b"Upgrade"),
-            (b"sec-websocket-accept", generate_accept_token(nonce)),
-            (b"upgrade", b"WebSocket"),
-            (b"x-foo", b"bar"),
-        ],
-    )
+    assert response.status_code == 101
+    assert sorted(response.headers) == [
+        (b"connection", b"Upgrade"),
+        (b"sec-websocket-accept", generate_accept_token(nonce)),
+        (b"upgrade", b"WebSocket"),
+        (b"x-foo", b"bar"),
+    ]
 
 
 @pytest.mark.parametrize("accept_subprotocol", ["one", "two"])
@@ -298,7 +286,7 @@ def test_protocol_error() -> None:
 
 def _make_handshake_rejection(
     status_code: int, body: Optional[bytes] = None
-) -> List[Event]:
+) -> List[h11.Event]:
     client = h11.Connection(h11.CLIENT)
     server = WSConnection(SERVER)
     nonce = generate_nonce()
@@ -333,7 +321,7 @@ def _make_handshake_rejection(
     events = []
     while True:
         event = client.next_event()
-        events.append(event)
+        events.append(cast(h11.Event, event))
         if isinstance(event, h11.EndOfMessage):
             return events
 
